@@ -438,3 +438,18 @@ class Client:
 
     def stock_insider_sentiment(self, symbol, _from, to):
         return self._get("/stock/insider-sentiment", params={"symbol": symbol, "from": _from, "to": to})
+
+    def stock_lobbying(self, symbol, _from, to):
+        return self._get("/stock/lobbying", params={"symbol": symbol, "from": _from, "to": to})
+
+    def bond_profile(self, **params):
+        return self._get("/bond/profile", params=params)
+
+    def bond_price(self, isin, _from, to):
+        return self._get("/bond/price", params={"isin": isin, "from": _from, "to": to})
+
+    def stock_usa_spending(self, symbol, _from, to):
+        return self._get("/stock/usa-spending", params={"symbol": symbol, "from": _from, "to": to})
+
+    def sector_metric(self, region):
+        return self._get("/sector/metrics", params={"region": region})
